pub unsafe extern "C" fn ccap_set_error_callback(
callback: CcapErrorCallback,
userData: *mut c_void,
) -> boolExpand description
@brief Set error callback for all camera operations @param callback Error callback function (NULL to remove callback) @param userData User data passed to callback @return true on success, false on failure @note This callback will be used by all provider instances